@@ -4,8 +4,9 @@
     'name': 'Account Invoice History',
     'name_de_DE': 'Fakturierung Historisierung',
     'name_es_CO': 'Histórico de Facturación',
-    'name_es_ES': 'Histórico de Facturación',
-    'version': '1.2.0',
+    'name_es_ES': 'Histórico de facturación',
+    'name_fr_FR': 'Historisation facture',
+    'version': '1.4.0',
     'author': 'B2CK',
     'email': 'info@b2ck.com',
     'website': 'http://www.tryton.org/',
@@ -15,8 +16,7 @@
 ''',
     'description_es_CO': '''Histórico de Facturación a nivel de campos
 ''',
-    'description_es_ES': '''Histórico de Facturación a nivel de campos
-''',
+    'description_es_ES': 'Añade un histórico para los campos de factura',
     'description_fr_FR': '''Ajoute l'historisation au champs de la facture.
 ''',
     'depends': [
